@@ -183,6 +183,8 @@ public class FitsImage extends Image {
                 inp.readLArray(xdata);
                 inp.close();
 	    } catch(Exception e) {
+                System.err.println("Error in fits:"+e);
+                e.printStackTrace(System.err);
 		throw new Error("Error reading FITS data for file: "+fitsFile+"\n\nException was:"+e);
 	    }
 	    
@@ -238,8 +240,5 @@ public class FitsImage extends Image {
     
     public Header getHeader() {
 	return fitsHeader;
-    }		// Bytes are signed integers in Java, but unsigned
-		// in FITS, so if we are reading in a byte array
-		// we'll need to convert the negative values.
-
+    }
 }
