@@ -25,9 +25,11 @@ import java.io.BufferedReader;
 import java.io.InputStreamReader;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.zip.GZIPInputStream;
+import nom.tam.fits.FitsException;
 import nom.tam.fits.HeaderCard;
 import skyview.request.TextReplacer;
 
@@ -159,6 +161,10 @@ public class XMLSurvey implements Survey {
         /** Scale requested for image */
         private double imageScale;
         
+        /** The ImageGenerator if supplied */
+        private ImageGenerator generator;        
+        private String imageGeneratorString;
+        
         
 	private void updatePosition() {
 	    try {
@@ -226,6 +232,7 @@ public class XMLSurvey implements Survey {
             
 
             if (inImages && qName.equals("Images")) {
+                finishParsing();
                 throw new ParsingTermination();
             }
             
@@ -276,19 +283,15 @@ public class XMLSurvey implements Survey {
 		} else if (qName.equals("ImageGenerator")) {
 		    
 		    // This is the name of a class that can generate image names dynamically.
-		    skyview.survey.ImageGenerator gen = 
+		    generator = 
 		      (skyview.survey.ImageGenerator) skyview.util.Utilities.newInstance(
 		         s, "skyview.survey");
-		    if (gen == null) {
+		    if (generator == null) {
 			throw new Error("Unable to create image generator:"+s);
-		    } 
-		    try {
-		        gen.getImages(ra, dec, requestSize, images);
-		    } catch (Exception e) {
-			System.err.println("Unable to invoke ImageGenerator:"+s+"\nException: "+e);
-                        e.printStackTrace(System.err);
-                        
 		    }
+                    imageGeneratorString = s;
+                    // Defer the actual generation of images until we
+                    // actually leave the Images element.
 		    
 	        } else {
 		    // Everything else goes into the Settings.  However
@@ -302,6 +305,18 @@ public class XMLSurvey implements Survey {
 		}
 	    }
         }
+        
+        void finishParsing() {
+            try {
+                if (generator != null) {
+		    generator.getImages(ra, dec, requestSize, images);
+                }
+            } catch (Exception e) {
+                System.err.println("Unable to invoke ImageGenerator:"+imageGeneratorString+"\nException: "+e);
+                e.printStackTrace(System.err);                        
+            }
+
+        }
 
         public void characters(char[] arr, int start, int len) {
 	    if (active) {
@@ -546,7 +561,6 @@ public class XMLSurvey implements Survey {
 	if (images.size() == 0) {
 	    return new Image[0];
 	} else {
-	    Image[] list       = new Image[images.size()];
 	    
 	    // Create the image factory
 	    ImageFactory imFac = (ImageFactory) 
@@ -554,11 +568,34 @@ public class XMLSurvey implements Survey {
 	    if (imFac == null) {
 		throw new Error("Unable to create image factory");
 	    }
+            List<Image> imageList = new ArrayList<Image>();
+            System.err.println("Loading images:"+images.size());
 	    for (int i=0; i<images.size(); i += 1) {
 		String s = images.get(i);
-		list[i]  = imFac.factory(s);
+                try {
+                    System.err.println("At image:"+i+" "+s);
+		    Image img  = imFac.factory(s);
+                    imageList.add(img);
+                    System.err.println("Image created:"+img);
+                } catch (Error e) {
+                    System.err.println("Here");
+                    System.err.println("keys:");
+                    for (String key: Settings.getKeys()) {
+                        System.err.print(" "+key);                        
+                    }
+                    System.err.println();
+                    System.err.println("Settings:"+Settings.has("AllowFitsErrors"));
+                    if (Settings.has("AllowFitsErrors")) {
+                        System.err.println("Continuing");
+                        continue;  
+                    } else {
+                        System.err.println("Rethrowing");
+                        throw e;  // Just rethrow error.
+                    }
+                }
+                System.err.println("Finished index:"+i);
 	    }
-	    return list;
+	    return imageList.toArray(new Image[0]);
 	}
     }
     
